@@ -1,6 +1,9 @@
 pub(crate) mod configmaps;
 pub(crate) mod contexts;
+pub(crate) mod cronjobs;
+pub(crate) mod daemonsets;
 pub(crate) mod deployments;
+pub(crate) mod jobs;
 pub(crate) mod key_binding;
 pub(crate) mod metrics;
 pub(crate) mod models;
@@ -8,33 +11,40 @@ pub(crate) mod nodes;
 pub(crate) mod ns;
 pub(crate) mod pods;
 pub(crate) mod replicasets;
+pub(crate) mod secrets;
 pub(crate) mod statefulsets;
 pub(crate) mod svcs;
 mod utils;
 
-use self::{
-  configmaps::KubeConfigMap,
-  contexts::KubeContext,
-  deployments::KubeDeployment,
-  key_binding::DEFAULT_KEYBINDING,
-  metrics::KubeNodeMetrics,
-  models::{LogsState, ScrollableTxt, StatefulTable, TabRoute, TabsState},
-  nodes::KubeNode,
-  ns::KubeNs,
-  pods::{KubeContainer, KubePod},
-  replicasets::KubeReplicaSet,
-  statefulsets::KubeStatefulSet,
-  svcs::KubeSvc,
-};
-use super::cmd::IoCmdEvent;
-use super::network::{stream::IoStreamEvent, IoEvent};
-
 use anyhow::anyhow;
 use kube::config::Kubeconfig;
 use kubectl_view_allocations::{GroupBy, QtyByQualifier};
 use tokio::sync::mpsc::Sender;
 use tui::layout::Rect;
 
+use self::{
+  configmaps::KubeConfigMap,
+  contexts::KubeContext,
+  cronjobs::KubeCronJob,
+  daemonsets::KubeDaemonSet,
+  deployments::KubeDeployment,
+  jobs::KubeJob,
+  key_binding::DEFAULT_KEYBINDING,
+  metrics::KubeNodeMetrics,
+  models::{LogsState, ScrollableTxt, StatefulList, StatefulTable, TabRoute, TabsState},
+  nodes::KubeNode,
+  ns::KubeNs,
+  pods::{KubeContainer, KubePod},
+  replicasets::KubeReplicaSet,
+  secrets::KubeSecret,
+  statefulsets::KubeStatefulSet,
+  svcs::KubeSvc,
+};
+use super::{
+  cmd::IoCmdEvent,
+  network::{stream::IoStreamEvent, IoEvent},
+};
+
 #[derive(Clone, Copy, PartialEq, Debug)]
 pub enum ActiveBlock {
   Help,
@@ -52,6 +62,11 @@ pub enum ActiveBlock {
   Yaml,
   Contexts,
   Utilization,
+  Jobs,
+  DaemonSets,
+  CronJobs,
+  Secrets,
+  More,
 }
 
 #[derive(Clone, PartialEq, Debug)]
@@ -97,6 +112,10 @@ pub struct Data {
   pub stateful_sets: StatefulTable<KubeStatefulSet>,
   pub replica_sets: StatefulTable<KubeReplicaSet>,
   pub deployments: StatefulTable<KubeDeployment>,
+  pub jobs: StatefulTable<KubeJob>,
+  pub daemon_sets: StatefulTable<KubeDaemonSet>,
+  pub cronjobs: StatefulTable<KubeCronJob>,
+  pub secrets: StatefulTable<KubeSecret>,
   pub logs: LogsState,
   pub describe_out: ScrollableTxt,
   pub metrics: StatefulTable<(Vec<String>, Option<QtyByQualifier>)>,
@@ -120,6 +139,7 @@ pub struct App {
   pub should_quit: bool,
   pub main_tabs: TabsState,
   pub context_tabs: TabsState,
+  pub more_resources_menu: StatefulList<(String, ActiveBlock)>,
   pub show_info_bar: bool,
   pub is_loading: bool,
   pub is_streaming: bool,
@@ -157,6 +177,10 @@ impl Default for Data {
       stateful_sets: StatefulTable::new(),
       replica_sets: StatefulTable::new(),
       deployments: StatefulTable::new(),
+      jobs: StatefulTable::new(),
+      daemon_sets: StatefulTable::new(),
+      cronjobs: StatefulTable::new(),
+      secrets: StatefulTable::new(),
       selected: Selected {
         ns: None,
         pod: None,
@@ -261,6 +285,42 @@ impl Default for App {
             id: RouteId::Home,
           },
         },
+        TabRoute {
+          title: format!("Jobs {}", DEFAULT_KEYBINDING.jump_to_jobs.key),
+          route: Route {
+            active_block: ActiveBlock::Jobs,
+            id: RouteId::Home,
+          },
+        },
+        TabRoute {
+          title: format!("DaemonSets {}", DEFAULT_KEYBINDING.jump_to_daemonsets.key),
+          route: Route {
+            active_block: ActiveBlock::DaemonSets,
+            id: RouteId::Home,
+          },
+        },
+        TabRoute {
+          title: format!("More {}", DEFAULT_KEYBINDING.jump_to_more_resources.key),
+          route: Route {
+            active_block: ActiveBlock::More,
+            id: RouteId::Home,
+          },
+        },
+      ]),
+      more_resources_menu: StatefulList::with_items(vec![
+        ("CronJobs".into(), ActiveBlock::CronJobs),
+        ("Secrets".into(), ActiveBlock::Secrets),
+        // ("Replication Controllers".into(), ActiveBlock::RplCtrl),
+        // ("Persistent Volume Claims".into(), ActiveBlock::RplCtrl),
+        // ("Persistent Volumes".into(), ActiveBlock::RplCtrl),
+        // ("Storage Classes".into(), ActiveBlock::RplCtrl),
+        // ("Roles".into(), ActiveBlock::RplCtrl),
+        // ("Role Bindings".into(), ActiveBlock::RplCtrl),
+        // ("Cluster Roles".into(), ActiveBlock::RplCtrl),
+        // ("Cluster Role Bindings".into(), ActiveBlock::RplCtrl),
+        // ("Service Accounts".into(), ActiveBlock::RplCtrl),
+        // ("Ingresses".into(), ActiveBlock::RplCtrl),
+        // ("Network Policies".into(), ActiveBlock::RplCtrl),
       ]),
       show_info_bar: true,
       is_loading: false,
@@ -393,7 +453,17 @@ impl App {
 
   pub fn get_prev_route(&self) -> &Route {
     // get the previous route
-    &self.navigation_stack[self.navigation_stack.len() - 2]
+    self.get_nth_route_from_last(1)
+  }
+
+  pub fn get_nth_route_from_last(&self, index: usize) -> &Route {
+    // get the previous route by index
+    let index = self.navigation_stack.len() - (index + 1);
+    if index > 0 {
+      &self.navigation_stack[index]
+    } else {
+      &self.navigation_stack[0]
+    }
   }
 
   pub fn cycle_main_routes(&mut self) {
@@ -427,6 +497,61 @@ impl App {
     self.refresh = true;
   }
 
+  pub async fn cache_all_resource_data(&mut self) {
+    self.dispatch(IoEvent::GetPods).await;
+    self.dispatch(IoEvent::GetServices).await;
+    self.dispatch(IoEvent::GetConfigMaps).await;
+    self.dispatch(IoEvent::GetStatefulSets).await;
+    self.dispatch(IoEvent::GetReplicaSets).await;
+    self.dispatch(IoEvent::GetDeployments).await;
+    self.dispatch(IoEvent::GetJobs).await;
+    self.dispatch(IoEvent::GetDaemonSets).await;
+    self.dispatch(IoEvent::GetCronJobs).await;
+    self.dispatch(IoEvent::GetSecrets).await;
+  }
+
+  pub async fn dispatch_by_active_block(&mut self, active_block: ActiveBlock) {
+    match active_block {
+      ActiveBlock::Pods | ActiveBlock::Containers => {
+        self.dispatch(IoEvent::GetPods).await;
+      }
+      ActiveBlock::Services => {
+        self.dispatch(IoEvent::GetServices).await;
+      }
+      ActiveBlock::ConfigMaps => {
+        self.dispatch(IoEvent::GetConfigMaps).await;
+      }
+      ActiveBlock::StatefulSets => {
+        self.dispatch(IoEvent::GetStatefulSets).await;
+      }
+      ActiveBlock::ReplicaSets => {
+        self.dispatch(IoEvent::GetReplicaSets).await;
+      }
+      ActiveBlock::Deployments => {
+        self.dispatch(IoEvent::GetDeployments).await;
+      }
+      ActiveBlock::Jobs => {
+        self.dispatch(IoEvent::GetJobs).await;
+      }
+      ActiveBlock::DaemonSets => {
+        self.dispatch(IoEvent::GetDaemonSets).await;
+      }
+      ActiveBlock::CronJobs => {
+        self.dispatch(IoEvent::GetCronJobs).await;
+      }
+      ActiveBlock::Secrets => {
+        self.dispatch(IoEvent::GetSecrets).await;
+      }
+      ActiveBlock::Logs => {
+        if !self.is_streaming {
+          // do not tail to avoid duplicates
+          self.dispatch_stream(IoStreamEvent::GetPodLogs(false)).await;
+        }
+      }
+      _ => {}
+    }
+  }
+
   pub async fn on_tick(&mut self, first_render: bool) {
     // Make one time requests on first render or refresh
     if self.refresh {
@@ -436,13 +561,7 @@ impl App {
       }
       self.dispatch(IoEvent::GetKubeConfig).await;
       // call these once to pre-load data
-      self.dispatch(IoEvent::GetPods).await;
-      self.dispatch(IoEvent::GetServices).await;
-      self.dispatch(IoEvent::GetConfigMaps).await;
-      self.dispatch(IoEvent::GetStatefulSets).await;
-      self.dispatch(IoEvent::GetReplicaSets).await;
-      self.dispatch(IoEvent::GetDeployments).await;
-
+      self.cache_all_resource_data().await;
       self.refresh = false;
     }
     // make network requests only in intervals to avoid hogging up the network
@@ -455,32 +574,14 @@ impl App {
           }
           self.dispatch(IoEvent::GetNamespaces).await;
           self.dispatch(IoEvent::GetNodes).await;
-          match self.get_current_route().active_block {
-            ActiveBlock::Pods | ActiveBlock::Containers => {
-              self.dispatch(IoEvent::GetPods).await;
-            }
-            ActiveBlock::Services => {
-              self.dispatch(IoEvent::GetServices).await;
-            }
-            ActiveBlock::ConfigMaps => {
-              self.dispatch(IoEvent::GetConfigMaps).await;
-            }
-            ActiveBlock::StatefulSets => {
-              self.dispatch(IoEvent::GetStatefulSets).await;
-            }
-            ActiveBlock::ReplicaSets => {
-              self.dispatch(IoEvent::GetReplicaSets).await;
-            }
-            ActiveBlock::Deployments => {
-              self.dispatch(IoEvent::GetDeployments).await;
-            }
-            ActiveBlock::Logs => {
-              if !self.is_streaming {
-                // do not tail to avoid duplicates
-                self.dispatch_stream(IoStreamEvent::GetPodLogs(false)).await;
-              }
-            }
-            _ => {}
+
+          let active_block = self.get_current_route().active_block;
+          if active_block == ActiveBlock::Namespaces {
+            self
+              .dispatch_by_active_block(self.get_prev_route().active_block)
+              .await;
+          } else {
+            self.dispatch_by_active_block(active_block).await;
           }
         }
         RouteId::Utilization => {
@@ -539,8 +640,7 @@ mod test_utils {
     assert_ne!(yaml, "".to_string());
 
     let res_list: serde_yaml::Result<ObjectList<K>> = serde_yaml::from_str(&*yaml);
-    assert!(res_list.is_ok());
-
+    assert!(res_list.is_ok(), "{:?}", res_list.err());
     res_list.unwrap()
   }
 
@@ -553,10 +653,10 @@ mod test_utils {
   }
 
   #[macro_export]
-  macro_rules! map {
+  macro_rules! map_string_object {
     // map-like
     ($($k:expr => $v:expr),* $(,)?) => {
-        std::iter::Iterator::collect(std::array::IntoIter::new([$(($k.to_string(), $v.to_string()),)*]))
+        std::iter::Iterator::collect(std::array::IntoIter::new([$(($k.to_string(), $v),)*]))
     };
   }
 }
@@ -589,6 +689,10 @@ mod tests {
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetStatefulSets);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetReplicaSets);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetDeployments);
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetJobs);
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetDaemonSets);
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetCronJobs);
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetSecrets);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetNamespaces);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetNodes);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetPods);
