@@ -1,9 +1,3 @@
-use super::super::app::App;
-use super::utils::{
-  layout_block_active, loading, style_highlight, style_primary, style_secondary, table_header_style,
-};
-use super::HIGHLIGHT;
-
 use tui::{
   backend::Backend,
   layout::{Constraint, Rect},
@@ -11,6 +5,15 @@ use tui::{
   Frame,
 };
 
+use super::{
+  utils::{
+    layout_block_active, loading, style_highlight, style_primary, style_secondary,
+    table_header_style,
+  },
+  HIGHLIGHT,
+};
+use crate::app::App;
+
 pub fn draw_contexts<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
   let title = format!("Contexts [{}]", app.data.contexts.items.len());
   let block = layout_block_active(title.as_str());
